@@ -4,7 +4,7 @@ import time
 k_opti_lab_socket_port = 8080
 
 
-class ParallelClient():
+class ParallelClient:
     address = ""
     port = -1
     client_runner = None
@@ -20,6 +20,13 @@ class ParallelClient():
         # Set use of protobuf as communication protocol
         self.use_protobuf = use_protobuf
 
+    def __enter__(self):
+        self.connect()
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.disconnect()
+
     def connect(self):
         """Connect Parallel front-end interface to the service"""
         self.client_runner = frontend_client_runner.FrontendClientRunner(
