@@ -1,7 +1,6 @@
-from . import routing_problem
-from . import scheduling_connector_factory
-from . import scheduling_problem
-from . import employees_scheduling_problem
+from .pllai_routing_toolbox import routing_problem
+from .pllai_scheduling_toolbox import scheduling_problem, scheduling_connector_factory
+
 
 def get_connector_factory(model_type):
     """Returns the factory building objects connecting
@@ -22,4 +21,4 @@ def BuildEmployeesSchedulerToVehicleRoutingConverter():
     """Builds and returns a new instance of a converter
     to transform and connect Employees Scheduling problem to Vehicle Routing problems"""
     return ModelConnector(scheduling_problem.SchedulingModelType.EMPLOYEES_SCHEDULING,
-        routing_problem.RoutingModelType.VRP)
+                          routing_problem.RoutingModelType.VRP)
