@@ -14,28 +14,42 @@ k_condition = Condition()
 k_queue = []
 k_current_model = None
 k_process_completed = "__PROCESS_COMPLETED__"
+k_health_message = "__HEALTH_CHECK_STATUS_OK__"
+k_error_message = "__ERROR_MESSAGE__"
+k_info_message = "__INFO_MESSAGE__"
 
 
 def on_message(ws, message):
     global k_current_model
     global k_queue
     global k_condition
-    if k_current_model is None:
-        msg = "The model is not set, return"
-        logging.info(msg)
-        print(msg)
+    if isinstance(message, str) and message.startswith(k_health_message):
+        pass
+    elif isinstance(message, str) and message.startswith(k_error_message):
+        logging.info(message)
+        print("Received an error message from the back-end server, return")
         return
-
-    if message == k_process_completed:
-        k_condition.acquire()
-
-        # Append the message to the queue
-        k_queue.append(message)
-        k_condition.notify()
-        k_condition.release()
+    elif isinstance(message, str) and message.startswith(k_info_message):
+        logging.info(message)
+        print(message)
     else:
-        # Proceed in parsing the protobuf message
-        k_current_model.on_message(message)
+        if k_current_model is None:
+            msg = "The model is not set, return"
+            logging.info(msg)
+            print(msg)
+            return
+
+        if isinstance(message, str) and message.startswith(k_process_completed):
+            k_condition.acquire()
+
+            # Append the message to the queue
+            k_queue.append(message)
+            k_condition.notify()
+            k_condition.release()
+        else:
+            # Proceed in parsing the protobuf message
+            k_current_model.on_message(message)
+
 
 def on_error(ws, error):
     logging.error(error)
@@ -53,7 +67,7 @@ def on_open(ws):
     print(msg)
 
 
-class FrontendClientRunner():
+class FrontendClientRunner:
     address = ""
     port = 0
     websocket = None
@@ -100,7 +114,9 @@ class FrontendClientRunner():
                                                     on_message=on_message,
                                                     on_error=on_error,
                                                     on_close=on_close)
+
             self.websocket.on_open = on_open
+
             # self.websocket.run_forever()
             th = threading.Thread(
                 target=self.connect_to_server_impl, args=(
@@ -114,6 +130,8 @@ class FrontendClientRunner():
 
     def disconnect_from_server(self):
         # Initiate closing protocol with server
+        if not self.websocket or not self.websocket.sock:
+            return
         self.websocket.sock.send("__CLIENT_LOG_OFF__")
 
         # Wait to logoff from server
